==> estateplat-common-1.2.3-20180831.073348-171-sources.jar: cn/gtmap/estateplat/model/server/core/TaskInfo.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.estateplat.utils.Constants;
import org.apache.commons.lang3.StringUtils;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * .
 * <p/>
 * 项目新建的基本信息参数
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-3-16
 */
public class TaskInfo implements Xmxx, Serializable {

    /***************
     * zdd 20160128后的所有批量发证前台页面参数必须以BdcXmRel list对象方式传入
     * 统一处理逻辑 并且匹配的批量时可以确定权籍id与原项目ID对应关系  后续将project对象其他关系字段删除
     ***************/
    private List<BdcXmRel> bdcXmRelList;

    private String workFlowDefId;

    private String djId; //地籍信息主键


    private String yxmid; //原项目信息主键

    private String bdcdyh;

    private String zdzhh;//宗地宗海号

    private String bdclx;//不动产类型

    private String userId;
    private String taskid;

    private String dcbIndex;//zdd 逻辑幢主键
    private List<String> dcbIndexs;

    private List<String> djIds;//zdd 当流程选择多个不动产单元时的 地籍参数
    private List<String> bdcdyhs;//zdd 批量选择多个不动产单元时的 不动产单元号
    private List<String> yxmids;//zdd 当流程选择多个原项目信息时 项目ID参数

    private String workflowProid; //zdd 创建工作流时 平台库存储记录的proid
    private String msg;//返回的信息
    private String tdids;
    private String gdproid;//zdd 所有过渡匹配项目  必须要有gdproid
    private String yqlid;//zdd 原权利ID
    private String ybdcdyid; //原不动产单元id
    private List<String> ybdcdyids;
    private String gdsyqid;//zdd 过渡 房屋所有权/土地使用权 主键
    private String djbid;//zdd 项目登记薄ID
    private String gdid;

    //	转发节点名称
    private String zfjdmc;
    //	当前节点名称
    private String dqjdmc;
    public String getDqjdmc() {
        return dqjdmc;
    }

    public void setDqjdmc(String dqjdmc) {
        this.dqjdmc = dqjdmc;
    }



    public List<BdcXmRel> getBdcXmRelList() {
        return bdcXmRelList;
    }

    public void setBdcXmRelList(List<BdcXmRel> bdcXmRelList) {
        this.bdcXmRelList = bdcXmRelList;
    }

    public String getDjbid() {
        return djbid;
    }

    public void setDjbid(String djbid) {
        this.djbid = djbid;
    }

    public String getYqlid() {
        return yqlid;
    }

    public void setYqlid(String yqlid) {
        this.yqlid = yqlid;
    }


    public String getGdsyqid() {
        return gdsyqid;
    }

    public void setGdsyqid(String gdsyqid) {
        this.gdsyqid = gdsyqid;
    }

    public List<String> getYbdcdyids() {
        return ybdcdyids;
    }

    public void setYbdcdyids(List<String> ybdcdyids) {
        this.ybdcdyids = ybdcdyids;
    }

    public List<String> getBdcdyhs() {
        return bdcdyhs;
    }

    public void setBdcdyhs(List<String> bdcdyhs) {
        if (bdcdyhs != null && bdcdyhs.size() == 1) {
            List<String> tempbdcdyhs = new ArrayList<String>();
            String[] bdcdyhArray = bdcdyhs.get(0).split(Constants.SPLIT_STR);
            for (String bdcdyh : bdcdyhArray) {
                if (StringUtils.isNotBlank(bdcdyh))
                    tempbdcdyhs.add(bdcdyh);
            }
            if (tempbdcdyhs != null && tempbdcdyhs.size() > 0)
                bdcdyhs = tempbdcdyhs;
        }
        this.bdcdyhs = bdcdyhs;
    }

    public String getDcbIndex() {
        return dcbIndex;
    }

    public void setDcbIndex(String dcbIndex) {
        this.dcbIndex = dcbIndex;
    }

    public List<String> getDcbIndexs() {
        return dcbIndexs;
    }

    public void setDcbIndexs(List<String> dcbIndexs) {
        this.dcbIndexs = dcbIndexs;
    }

    public String getWorkflowProid() {
        return workflowProid;
    }

    public void setWorkflowProid(String workflowProid) {
        this.workflowProid = workflowProid;
    }

    public List<String> getYxmids() {
        return yxmids;
    }

    public void setYxmids(List<String> yxmids) {
        if (yxmids != null && yxmids.size() == 1) {
            List<String> tempYxmids = new ArrayList<String>();
            String[] djidArray = yxmids.get(0).split(Constants.SPLIT_STR);
            for (String xmid : djidArray) {
                if (StringUtils.isNotBlank(xmid))
                    tempYxmids.add(xmid);
            }
            if (tempYxmids != null && tempYxmids.size() > 0) {
                yxmids = tempYxmids;
            }

        }
        this.yxmids = yxmids;
    }

    public List<String> getDjIds() {
        return djIds;
    }

    public void setDjIds(List<String> djIds) {
        if (djIds != null && djIds.size() == 1) {
            List<String> tempDjids = new ArrayList<String>();
            String[] djidArray = djIds.get(0).split(Constants.SPLIT_STR);
            for (String djid : djidArray) {
                if (StringUtils.isNotBlank(djid))
                    tempDjids.add(djid);
            }
            if (tempDjids != null && tempDjids.size() > 0) {
                djIds = tempDjids;
            }

        }
        this.djIds = djIds;
    }


    public String getDjId() {
        return djId;
    }

    public void setDjId(String djId) {
        this.djId = djId;
    }


    public String getYxmid() {
        return yxmid;
    }

    public void setYxmid(String yxmid) {
        this.yxmid = yxmid;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getZdzhh() {
        if (StringUtils.isBlank(zdzhh) && StringUtils.isNotBlank(bdcdyh) && bdcdyh.length() > 19) {
            zdzhh = bdcdyh.substring(0, 19);
        } else if (StringUtils.isBlank(zdzhh) && bdcdyhs != null && bdcdyhs.size() > 0) {
            if (bdcdyhs.get(0).length() > 19)
                zdzhh = bdcdyhs.get(0).substring(0, 19);
        }
        return zdzhh;
    }

    public void setZdzhh(String zdzhh) {
        this.zdzhh = zdzhh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getWorkFlowDefId() {
        return workFlowDefId;
    }

    public void setWorkFlowDefId(String workFlowDefId) {
        this.workFlowDefId = workFlowDefId;
    }

    public String getTaskid() {
        return taskid;
    }

    public void setTaskid(String taskid) {
        this.taskid = taskid;
    }


    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }


    public String getGdproid() {
        return gdproid;
    }

    public void setGdproid(String gdproid) {
        this.gdproid = gdproid;
    }

    public String getYbdcdyid() {
        return ybdcdyid;
    }

    public void setYbdcdyid(String ybdcdyid) {
        this.ybdcdyid = ybdcdyid;
    }



    public String getTdids() {
        return tdids;
    }

    public void setTdids(String tdids) {
        this.tdids = tdids;
    }

    public String getGdid() {
        return gdid;
    }

    public void setGdid(String gdid) {
        this.gdid = gdid;
    }



    public String getZfjdmc() {
        return zfjdmc;
    }

    public void setZfjdmc(String zfjdmc) {
        this.zfjdmc = zfjdmc;
    }

}

==> estateplat-common-1.2.4-20190730.081358-205-sources.jar: cn/gtmap/estateplat/model/server/core/TaskInfo.java <==
package cn.gtmap.estateplat.model.server.core;

import cn.gtmap.estateplat.utils.Constants;
import org.apache.commons.lang3.StringUtils;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * .
 * <p/>
 * 项目新建的基本信息参数
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-3-16
 */
public class TaskInfo implements Xmxx, Serializable {

    /***************
     * zdd 20160128后的所有批量发证前台页面参数必须以BdcXmRel list对象方式传入
     * 统一处理逻辑 并且匹配的批量时可以确定权籍id与原项目ID对应关系  后续将project对象其他关系字段删除
     ***************/

    private String proid;
    private String wiid;
    private String bh;//编号
    private String qllx;//权力类型
    private String djlx;//登记类型
    private String djyy;//登记原因
    private String bz; //备注
    private String dwdm;//单位代码
    private Date cjsj;//创建时间
    private String cjr;//创建人
    private String xmly;//项目来源
    private String sqlx;//申请类型
    private String bdcdyid;//不动产单元ID
    private String djsy;//登记事由
    private String zl;//坐落
    private String ybdcqzh;//原不动产权证号
    private String ybh;//原受理编号
    private String djzx;//登记子项



    private List<BdcXmRel> bdcXmRelList;

    private String workFlowDefId;

    private String djId; //地籍信息主键


    private String yxmid; //原项目信息主键

    private String bdcdyh;

    private String zdzhh;//宗地宗海号

    private String bdclx;//不动产类型

    private String userId;
    private String taskid;

    private String dcbIndex;//zdd 逻辑幢主键
    private List<String> dcbIndexs;

    private List<String> djIds;//zdd 当流程选择多个不动产单元时的 地籍参数
    private List<String> bdcdyhs;//zdd 批量选择多个不动产单元时的 不动产单元号
    private List<String> yxmids;//zdd 当流程选择多个原项目信息时 项目ID参数

    private String workflowProid; //zdd 创建工作流时 平台库存储记录的proid
    private String msg;//返回的信息
    private String tdids;
    private String gdproid;//zdd 所有过渡匹配项目  必须要有gdproid
    private String yqlid;//zdd 原权利ID
    private String ybdcdyid; //原不动产单元id
    private List<String> ybdcdyids;
    private String gdsyqid;//zdd 过渡 房屋所有权/土地使用权 主键
    private String djbid;//zdd 项目登记薄ID
    private String gdid;

    //	转发节点名称
    private String zfjdmc;
    //	当前节点名称
    private String dqjdmc;


    public String getBh() {
        return bh;
    }

    public void setBh(String bh) {
        this.bh = bh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getCjr() {
        return cjr;
    }

    public void setCjr(String cjr) {
        this.cjr = cjr;
    }

    public String getXmly() {
        return xmly;
    }

    public void setXmly(String xmly) {
        this.xmly = xmly;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getDjsy() {
        return djsy;
    }

    public void setDjsy(String djsy) {
        this.djsy = djsy;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getYbdcqzh() {
        return ybdcqzh;
    }

    public void setYbdcqzh(String ybdcqzh) {
        this.ybdcqzh = ybdcqzh;
    }

    public String getYbh() {
        return ybh;
    }

    public void setYbh(String ybh) {
        this.ybh = ybh;
    }

    public String getDjzx() {
        return djzx;
    }

    public void setDjzx(String djzx) {
        this.djzx = djzx;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getDqjdmc() {
        return dqjdmc;
    }

    public void setDqjdmc(String dqjdmc) {
        this.dqjdmc = dqjdmc;
    }



    public List<BdcXmRel> getBdcXmRelList() {
        return bdcXmRelList;
    }

    public void setBdcXmRelList(List<BdcXmRel> bdcXmRelList) {
        this.bdcXmRelList = bdcXmRelList;
    }

    public String getDjbid() {
        return djbid;
    }

    public void setDjbid(String djbid) {
        this.djbid = djbid;
    }

    public String getYqlid() {
        return yqlid;
    }

    public void setYqlid(String yqlid) {
        this.yqlid = yqlid;
    }


    public String getGdsyqid() {
        return gdsyqid;
    }

    public void setGdsyqid(String gdsyqid) {
        this.gdsyqid = gdsyqid;
    }

    public List<String> getYbdcdyids() {
        return ybdcdyids;
    }

    public void setYbdcdyids(List<String> ybdcdyids) {
        this.ybdcdyids = ybdcdyids;
    }

    public List<String> getBdcdyhs() {
        return bdcdyhs;
    }

    public void setBdcdyhs(List<String> bdcdyhs) {
        if (bdcdyhs != null && bdcdyhs.size() == 1) {
            List<String> tempbdcdyhs = new ArrayList<String>();
            String[] bdcdyhArray = bdcdyhs.get(0).split(Constants.SPLIT_STR);
            for (String bdcdyh : bdcdyhArray) {
                if (StringUtils.isNotBlank(bdcdyh))
                    tempbdcdyhs.add(bdcdyh);
            }
            if (tempbdcdyhs != null && tempbdcdyhs.size() > 0)
                bdcdyhs = tempbdcdyhs;
        }
        this.bdcdyhs = bdcdyhs;
    }

    public String getDcbIndex() {
        return dcbIndex;
    }

    public void setDcbIndex(String dcbIndex) {
        this.dcbIndex = dcbIndex;
    }

    public List<String> getDcbIndexs() {
        return dcbIndexs;
    }

    public void setDcbIndexs(List<String> dcbIndexs) {
        this.dcbIndexs = dcbIndexs;
    }

    public String getWorkflowProid() {
        return workflowProid;
    }

    public void setWorkflowProid(String workflowProid) {
        this.workflowProid = workflowProid;
    }

    public List<String> getYxmids() {
        return yxmids;
    }

    public void setYxmids(List<String> yxmids) {
        if (yxmids != null && yxmids.size() == 1) {
            List<String> tempYxmids = new ArrayList<String>();
            String[] djidArray = yxmids.get(0).split(Constants.SPLIT_STR);
            for (String xmid : djidArray) {
                if (StringUtils.isNotBlank(xmid))
                    tempYxmids.add(xmid);
            }
            if (tempYxmids != null && tempYxmids.size() > 0) {
                yxmids = tempYxmids;
            }

        }
        this.yxmids = yxmids;
    }

    public List<String> getDjIds() {
        return djIds;
    }

    public void setDjIds(List<String> djIds) {
        if (djIds != null && djIds.size() == 1) {
            List<String> tempDjids = new ArrayList<String>();
            String[] djidArray = djIds.get(0).split(Constants.SPLIT_STR);
            for (String djid : djidArray) {
                if (StringUtils.isNotBlank(djid))
                    tempDjids.add(djid);
            }
            if (tempDjids != null && tempDjids.size() > 0) {
                djIds = tempDjids;
            }

        }
        this.djIds = djIds;
    }


    public String getDjId() {
        return djId;
    }

    public void setDjId(String djId) {
        this.djId = djId;
    }


    public String getYxmid() {
        return yxmid;
    }

    public void setYxmid(String yxmid) {
        this.yxmid = yxmid;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getZdzhh() {
        if (StringUtils.isBlank(zdzhh) && StringUtils.isNotBlank(bdcdyh) && bdcdyh.length() > 19) {
            zdzhh = bdcdyh.substring(0, 19);
        } else if (StringUtils.isBlank(zdzhh) && bdcdyhs != null && bdcdyhs.size() > 0) {
            if (bdcdyhs.get(0).length() > 19)
                zdzhh = bdcdyhs.get(0).substring(0, 19);
        }
        return zdzhh;
    }

    public void setZdzhh(String zdzhh) {
        this.zdzhh = zdzhh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getWorkFlowDefId() {
        return workFlowDefId;
    }

    public void setWorkFlowDefId(String workFlowDefId) {
        this.workFlowDefId = workFlowDefId;
    }

    public String getTaskid() {
        return taskid;
    }

    public void setTaskid(String taskid) {
        this.taskid = taskid;
    }


    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }


    public String getGdproid() {
        return gdproid;
    }

    public void setGdproid(String gdproid) {
        this.gdproid = gdproid;
    }

    public String getYbdcdyid() {
        return ybdcdyid;
    }

    public void setYbdcdyid(String ybdcdyid) {
        this.ybdcdyid = ybdcdyid;
    }



    public String getTdids() {
        return tdids;
    }

    public void setTdids(String tdids) {
        this.tdids = tdids;
    }

    public String getGdid() {
        return gdid;
    }

    public void setGdid(String gdid) {
        this.gdid = gdid;
    }



    public String getZfjdmc() {
        return zfjdmc;
    }

    public void setZfjdmc(String zfjdmc) {
        this.zfjdmc = zfjdmc;
    }

}
